[![PyPI](https://img.shields.io/pypi/v/gmspy)](https://pypi.org/project/gmspy/)
[![Downloads](https://static.pepy.tech/badge/gmspy)](https://pepy.tech/project/gmspy)
[![Documentation Status](https://readthedocs.org/projects/gmspy/badge/?version=latest)](https://gmspy.readthedocs.io/en/latest/?badge=latest)
![license](https://img.shields.io/github/license/yexiang1992/gmspy)
[![CodeFactor](https://www.codefactor.io/repository/github/yexiang1992/gmspy/badge)](https://www.codefactor.io/repository/github/yexiang1992/gmspy)

``gmspy`` is a python package for dealing with ``ground motions time-histories`` induced by earthquakes, including various ``intensity measures (IMs)``, ``elastic response spectra``, ``constant ductility response spectra``, ``pre-processing``, etc.

To use, install `gmspy` from [gmspy-PyPI](https://pypi.org/project/gmspy/):

```python
pip install --upgrade gmspy
```

Document: [https://gmspy.readthedocs.io/en/latest/](https://gmspy.readthedocs.io/en/latest/)

### License

This software is published under the [GPLv3 license](https://www.gnu.org/licenses/gpl-3.0.en.html).